@@ -73,7 +73,7 @@ def test_no_permission_buckets(mock_connection, mock_minio):
     bad_gcs_path = "gs://random/path"
     # Access private buckets without credentials
     mock_minio.return_value = Minio("s3.us.cloud-object-storage.appdomain.cloud", secure=True)
-    mock_connection.side_effect = error.AccessDenied(None)
+    mock_connection.side_effect = error.AccessDenied()
     with pytest.raises(error.AccessDenied):
         kfserving.Storage.download(bad_s3_path)
     mock_connection.side_effect = exceptions.Forbidden(None)
